/***************************************************************************
                         helpdialog.cpp  -  description
                             -------------------
    begin                : Fr Nov 15 13:44:19 CEST 2001
    copyright            : (C) 2002 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "helpdialog.h"
#include "krenameimpl.h"

// Qt includes
#include <qcombobox.h>
#include <qlayout.h>
#include <qlineedit.h>

// KDE includes
#include <klocale.h>
#include <klistview.h>
#include <kpushbutton.h>
#include <kstdguiitem.h>

HelpDialog::HelpDialog( QWidget* parent,
    const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    resize( 500, 400 ); 
    setCaption( i18n( "Help" ) );
    HelpDialogLayout = new QVBoxLayout( this, 11, 6, "HelpDialogLayout"); 

    comboHeadline = new QComboBox( FALSE, this, "comboHeadline" );
    HelpDialogLayout->addWidget( comboHeadline );

    list = new KListView( this, "list" );
    list->addColumn( i18n( "Token" ) );
    list->addColumn( i18n( "Description" ) );
    HelpDialogLayout->addWidget( list );

    Layout1 = new QHBoxLayout( 0, 0, 6, "Layout1"); 
    QSpacerItem* spacer = new QSpacerItem( 91, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
    Layout1->addItem( spacer );

    buttonAdd = new KPushButton( this, "buttonAdd" );
    buttonAdd->setText( i18n( "&Add" ) );
    Layout1->addWidget( buttonAdd );

    buttonClose = createButton( KStdGuiItem::close(), this );
    Layout1->addWidget( buttonClose );
    HelpDialogLayout->addLayout( Layout1 );

    // signals and slots connections
    connect( buttonClose, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( buttonAdd, SIGNAL( clicked() ), this, SLOT( exec()  ) );
    connect( list, SIGNAL( executed(QListViewItem*) ), this, SLOT( exec() ) );
    connect( comboHeadline, SIGNAL( activated(int) ), this, SLOT(updateItems() ) );
}

HelpDialog::~HelpDialog()
{
}

void HelpDialog::remove( QString headline )
{
    if( map.contains( headline ) ) {
        map.remove( headline );
        icons.remove( headline );
        
        updateHeadline();                
        updateItems();
    }
}

void HelpDialog::exec()
{
    if(!list->currentItem())
        return;

    QString t = text->text();

    t.insert( text->cursorPosition(), list->currentItem()->text( 0 ) );
    text->setText( t );
}

void HelpDialog::updateItems()
{
    list->clear();
    QStringList items = map[comboHeadline->currentText()];

    for( unsigned int i = 0; i < items.count(); i++ ) {
        QString tmp = items[i];
        new KListViewItem( list, tmp.section( ";;", 0, 0 ), tmp.section( ";;", 1, 1 ) );
    }
}

void HelpDialog::updateHeadline()
{
    comboHeadline->clear();


    comboHeadline->insertItem( icons[m_first], m_first );    
    QMap<QString, QStringList>::Iterator it;
    for ( it = map.begin(); it != map.end(); ++it )
        if( it.key() != m_first )
            comboHeadline->insertItem( icons[it.key()], it.key() );    
}

void HelpDialog::add( QString headline, QStringList* commands, const QPixmap & icon, bool first )
{
    map.insert( headline, *commands );
    icons.insert( headline, icon );
    if( first )
        m_first = headline;
        
    updateHeadline();
    updateItems();
}

QStringList HelpDialog::tokens() const
{
    QStringList list;
    
#if QT_VERSION >= 0x030005
    // map.keys() seems only to be avaible in Qt >= 3.0.5
    QStringList keys = map.keys();
#else
    QStringList keys;
    QMap<QString, QStringList>::Iterator it;
    for ( it = map.begin(); it != map.end(); ++it )
        keys.append( it.key() );
#endif

    for( unsigned int i = 0; i < keys.count(); i++ )
        for( unsigned int z = 0; z < map[keys[i]].count(); z++ )
            list.append( map[keys[i]][z].section( ";;", 0, 0 ) );
        
    return list;
}

